==> cdktf-cdktf-provider-google_beta-3.0.1.tar.gz: package/lib/data-google-composer-image-versions/index.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataGoogleComposerImageVersionsConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_composer_image_versions#id DataGoogleComposerImageVersions#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_composer_image_versions#project DataGoogleComposerImageVersions#project}
    */
    readonly project?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_composer_image_versions#region DataGoogleComposerImageVersions#region}
    */
    readonly region?: string;
}
export interface DataGoogleComposerImageVersionsImageVersions {
}
export declare function dataGoogleComposerImageVersionsImageVersionsToTerraform(struct?: DataGoogleComposerImageVersionsImageVersions): any;
export declare class DataGoogleComposerImageVersionsImageVersionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataGoogleComposerImageVersionsImageVersions | undefined;
    set internalValue(value: DataGoogleComposerImageVersionsImageVersions | undefined);
    get imageVersionId(): string;
    get supportedPythonVersions(): string[];
}
export declare class DataGoogleComposerImageVersionsImageVersionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataGoogleComposerImageVersionsImageVersionsOutputReference;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/d/google_composer_image_versions google_composer_image_versions}
*/
export declare class DataGoogleComposerImageVersions extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "google_composer_image_versions";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/d/google_composer_image_versions google_composer_image_versions} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataGoogleComposerImageVersionsConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DataGoogleComposerImageVersionsConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _imageVersions;
    get imageVersions(): DataGoogleComposerImageVersionsImageVersionsList;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    resetRegion(): void;
    get regionInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf-cdktf-provider-google_beta-7.0.0.tar.gz: package/lib/data-google-composer-image-versions/index.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataGoogleComposerImageVersionsConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_composer_image_versions#id DataGoogleComposerImageVersions#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_composer_image_versions#project DataGoogleComposerImageVersions#project}
    */
    readonly project?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_composer_image_versions#region DataGoogleComposerImageVersions#region}
    */
    readonly region?: string;
}
export interface DataGoogleComposerImageVersionsImageVersions {
}
export declare function dataGoogleComposerImageVersionsImageVersionsToTerraform(struct?: DataGoogleComposerImageVersionsImageVersions): any;
export declare class DataGoogleComposerImageVersionsImageVersionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataGoogleComposerImageVersionsImageVersions | undefined;
    set internalValue(value: DataGoogleComposerImageVersionsImageVersions | undefined);
    get imageVersionId(): string;
    get supportedPythonVersions(): string[];
}
export declare class DataGoogleComposerImageVersionsImageVersionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataGoogleComposerImageVersionsImageVersionsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_composer_image_versions google_composer_image_versions}
*/
export declare class DataGoogleComposerImageVersions extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "google_composer_image_versions";
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_composer_image_versions google_composer_image_versions} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataGoogleComposerImageVersionsConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DataGoogleComposerImageVersionsConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _imageVersions;
    get imageVersions(): DataGoogleComposerImageVersionsImageVersionsList;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    resetRegion(): void;
    get regionInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
